==> data-3.9.1-sources.jar: org/thingsboard/server/common/data/notification/rule/trigger/TaskProcessingFailureTrigger.java <==
/**
 * Copyright © 2016-2024 The Thingsboard Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.thingsboard.server.common.data.notification.rule.trigger;

import lombok.Builder;
import lombok.Data;
import org.thingsboard.server.common.data.housekeeper.HousekeeperTask;
import org.thingsboard.server.common.data.id.EntityId;
import org.thingsboard.server.common.data.id.TenantId;
import org.thingsboard.server.common.data.notification.rule.trigger.config.NotificationRuleTriggerType;

@Data
@Builder
public class TaskProcessingFailureTrigger implements NotificationRuleTrigger {

    private final HousekeeperTask task;
    private final int attempt;
    private final Throwable error;

    @Override
    public NotificationRuleTriggerType getType() {
        return NotificationRuleTriggerType.TASK_PROCESSING_FAILURE;
    }

    @Override
    public TenantId getTenantId() {
        return task.getTenantId();
    }

    @Override
    public EntityId getOriginatorEntityId() {
        return task.getEntityId();
    }

    @Override
    public boolean deduplicate() {
        return false;
    }

}

==> data-4.2.1-sources.jar: org/thingsboard/server/common/data/notification/rule/trigger/TaskProcessingFailureTrigger.java <==
/**
 * Copyright © 2016-2025 The Thingsboard Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.thingsboard.server.common.data.notification.rule.trigger;

import lombok.Builder;
import lombok.Data;
import org.thingsboard.server.common.data.housekeeper.HousekeeperTask;
import org.thingsboard.server.common.data.id.EntityId;
import org.thingsboard.server.common.data.id.TenantId;
import org.thingsboard.server.common.data.notification.rule.trigger.config.NotificationRuleTriggerType;

import java.io.Serial;

@Data
@Builder
public class TaskProcessingFailureTrigger implements NotificationRuleTrigger {

    @Serial
    private static final long serialVersionUID = 5606203770553105345L;

    private final HousekeeperTask task;
    private final int attempt;
    private final Throwable error;

    @Override
    public NotificationRuleTriggerType getType() {
        return NotificationRuleTriggerType.TASK_PROCESSING_FAILURE;
    }

    @Override
    public TenantId getTenantId() {
        return task.getTenantId();
    }

    @Override
    public EntityId getOriginatorEntityId() {
        return task.getEntityId();
    }

}
